%define _with_lucene 0

Name:           pdfbox
Version:        1.8.7
Release:        %mkrel 1
Summary:        Java library for working with PDF documents
Group:          Development/Java
License:        ASL 2.0
URL:            http://pdfbox.apache.org/
Source0:        http://www.apache.org/dist/pdfbox/%{version}/%{name}-%{version}-src.zip
#Don't download anything
Patch0:         %{name}-nodownload.patch
#Use sysytem bitream-vera-sans-fonts instead of bundled fonts
Patch1:         %{name}-1.2.0-bitstream.patch

Patch2:         pdfbox-1.8.7-port-to-bouncycastle1.50.patch

BuildRequires:  ant
BuildRequires:  maven-local
BuildRequires:  maven-install-plugin
BuildRequires:  maven-war-plugin
BuildRequires:  apache-commons-logging
BuildRequires:  apache-rat-plugin
BuildRequires:  fonts-ttf-bitstream-vera
BuildRequires:  bouncycastle-mail
BuildRequires:  cobertura-maven-plugin
BuildRequires:  fontconfig
BuildRequires:  icu4j
BuildRequires:  javacc-maven-plugin
BuildRequires:  junit
BuildRequires:  lucene-demo >= 2.4.1
BuildRequires:  pcfi
BuildRequires:  log4j12

BuildArch:      noarch

Requires:       java >= 1:1.6.0
Requires:       fonts-ttf-bitstream-vera

Obsoletes:      %{name}-app <= 1.6.0-4
Provides:       %{name}-app = %{version}-%{release}

%description
Apache PDFBox is an open source Java PDF library for working with PDF
documents. This project allows creation of new PDF documents, manipulation of
existing documents and the ability to extract content from documents. Apache
PDFBox also includes several command line utilities. Apache PDFBox is
published under the Apache License v2.0.


%package        examples
Summary:        Examples for %{name}
Group:          Documentation

%description    examples
This package contains examples for %{name}.


%package        javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Provides:       fontbox-javadoc = %{version}-%{release}
Obsoletes:      fontbox-javadoc < %{version}-%{release}
Provides:       jempbox-javadoc = %{version}-%{release}
Obsoletes:      jempbox-javadoc < %{version}-%{release}

%description    javadoc
This package contains the API documentation for %{name}.


%package        ant
Summary:        Apache PDFBox for Ant
Group:          Development/Java

%description    ant
%{summary}.


%package -n     fontbox
Summary:        Apache FontBox
Group:          Development/Java

%description -n fontbox
FontBox is a Java library used to obtain low level information from font
files. FontBox is a subproject of Apache PDFBox.


%package -n     jempbox
Summary:        Apache JempBox
Group:          Development/Java

%description -n jempbox
JempBox is an open source Java library that implements Adobe's XMP(TM)
specification. JempBox is a subproject of Apache PDFBox.


%package -n     preflight
Summary:        Apache Preflight
Group:          Development/Java

%description -n preflight
The Apache Preflight library is an open source Java tool that implements 
a parser compliant with the ISO-19005 (PDF/A) specification. Preflight is a 
subproject of Apache PDFBox.


%package -n     xmpbox
Summary:        Apache XmpBox
Group:          Development/Java

%description -n xmpbox
The Apache XmpBox library is an open source Java tool that implements Adobe's
XMP(TM) specification.  It can be used to parse, validate and create xmp
contents.  It is mainly used by subproject preflight of Apache PDFBox. 
XmpBox is a subproject of Apache PDFBox.


%prep
%setup -q

%patch0 -p1 -b .nodownload
%patch1 -p1 -b .bitstream

# Skip testImageIOUtils
# https://issues.apache.org/jira/browse/PDFBOX-2084
sed -i -e "/TestImageIOUtils.java/d" pdfbox/pom.xml
# Remove unpackaged deps for the above tests
%pom_remove_dep net.java.dev.jai-imageio:jai-imageio-core-standalone pdfbox
%pom_remove_dep com.levigo.jbig2:levigo-jbig2-imageio pdfbox
rm -rf pdfbox/src/test/java/org/apache/pdfbox/util/TestImageIOUtils.java \
 pdfbox/src/test/java/org/apache/pdfbox/pdmodel/graphics/xobject/PDJpegTest.java \
 pdfbox/src/test/java/org/apache/pdfbox/pdmodel/graphics/xobject/PDCcittTest.java
sed -i -e /PDJpegTest/d pdfbox/src/test/java/org/apache/pdfbox/TestAll.java
sed -i -e /PDCcittTest/d pdfbox/src/test/java/org/apache/pdfbox/TestAll.java
sed -i -e /TestImageIOUtils/d pdfbox/src/test/java/org/apache/pdfbox/TestAll.java

%pom_remove_dep javax.activation:activation preflight

%pom_disable_module war

sed -i.ant "s|<artifactId>ant-nodeps</artifactId>|<artifactId>ant</artifactId>|" pom.xml */pom.xml

sed -i.log4j12 "s|<version>1.2.12</version>|<version>1.2.17</version>|" preflight*/pom.xml

#Disable lucene, not compatible with lucene 3.6
%pom_disable_module lucene
#Use jdk16 version of bcprov
sed -i -e s/jdk15/jdk16/g */pom.xml
# Don't build app (it's just a bundle of everything)
sed -i -e /app/d pom.xml
find -name '*.class' -delete
find -name '*.jar' -delete
#Fix line endings
sed -i -e 's|\r||' RELEASE-NOTES.txt
#Remove META-INF file that does not exist
sed -i -e '/META-INF/d' pdfbox/pom.xml
#Remove included fonts
rm -r pdfbox/src/main/resources/org/apache/pdfbox/resources/ttf

%pom_add_dep org.bouncycastle:bcpkix-jdk15on:1.50 %{name}
%patch2 -p0 -b .bouncycastle1.50

# TODO
rm -rf examples/src/main/java/org/apache/pdfbox/examples/signature/CreateSignature.java \
 examples/src/main/java/org/apache/pdfbox/examples/signature/CreateVisibleSignature.java

# Disable filtering
sed -i -e /filtering/d examples/pom.xml

%build
# install all libraries in _javadir
# NOTE: current guideline require all libraries must be installed in _javadir/%%name when JARs are > 2
%mvn_file :jempbox jempbox
%mvn_file :%{name} %{name}
%mvn_file :%{name}-ant %{name}-ant
%mvn_file :%{name}-examples %{name}-examples
%mvn_file :preflight preflight
%mvn_file :xmpbox xmpbox
%mvn_file :fontbox fontbox

# Merge paret poms in main package
%mvn_package :%{name} %{name}
%mvn_package :%{name}-parent %{name}
%mvn_package :%{name}-reactor %{name}

%mvn_package :fontbox fontbox
%mvn_package :jempbox jempbox
%mvn_package :preflight preflight
%mvn_package :xmpbox xmpbox

%mvn_build -s -- -Dadobefiles.jar=$(build-classpath pcfi)

%install
%mvn_install

#TODO - install/ship war

%files -f .mfiles-%{name}
%doc LICENSE.txt NOTICE.txt README.txt RELEASE-NOTES.txt

%files examples -f .mfiles-%{name}-examples
%doc LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt

%files ant -f .mfiles-%{name}-ant
%doc LICENSE.txt NOTICE.txt

%files -n fontbox -f .mfiles-fontbox
%doc LICENSE.txt NOTICE.txt

%files -n jempbox -f .mfiles-jempbox
%doc LICENSE.txt NOTICE.txt

%files -n preflight -f .mfiles-preflight
%doc LICENSE.txt NOTICE.txt

%files -n xmpbox -f .mfiles-xmpbox
%doc LICENSE.txt NOTICE.txt


%changelog
* Tue Dec 30 2014 daviddavid <daviddavid> 1.8.7-1.mga5
+ Revision: 807269
- Sync with fc21 (update to 1.8.7)

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.7.0-3.mga4
+ Revision: 508925
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.7.0-2.mga3
+ Revision: 362677
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 dmorgan <dmorgan> 1.7.0-1.mga3
+ Revision: 326570
- New version

* Mon Jan 09 2012 gil <gil> 1.6.0-3.mga2
+ Revision: 193617
- build fix
  modified line#157
- build fix
  added system pcfi support
  added system fonts-ttf-bitstream-vera support

* Thu Oct 06 2011 gil <gil> 1.6.0-2.mga2
+ Revision: 152481
- edit spec file
- edit spec file
- rebuilt with mvn, enable javadoc

* Thu Oct 06 2011 dmorgan <dmorgan> 1.6.0-1.mga2
+ Revision: 152446
- Do not build javadoc
- Try to build with ant
- Disable tests ( from gil)
- Add maven-surefire-provider-junit4 as BuildRequires
- Clean spec file

  + gil <gil>
    - update to 1.6.0
    - imported package pdfbox

